@@ -1,11 +1,14 @@
-package Class::Scaffold::App;
-use strict;
+use 5.008;
 use warnings;
+use strict;
+
+package Class::Scaffold::App;
+our $VERSION = '1.100760';
+# ABSTRACT: Base class for framework applications
 use Class::Scaffold::Environment;
 use Property::Lookup;
 use Error ':try';
-our $VERSION = '0.16';
-use base 'Class::Scaffold::Storable';
+use parent 'Class::Scaffold::Storable';
 __PACKAGE__->mk_boolean_accessors(qw(initialized));
 use IO::Handle;
 STDOUT->autoflush;
@@ -82,15 +85,22 @@ sub run_app {
     $self->app_finish;
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
-Class::Scaffold::App - large-scale OOP application support
+Class::Scaffold::App - Base class for framework applications
+
+=head1 VERSION
+
+version 1.100760
 
 =head1 SYNOPSIS
 
-    use base 'Class::Scaffold::App';
+    use parent 'Class::Scaffold::App';
 
     sub app_code {
         my $self = shift;
@@ -109,99 +119,64 @@ C<run_app()>.
 
 =head1 METHODS
 
-=over 4
-
-=item run_app
+=head2 run_app
 
 This is the main method that application subclasses should invoke. It calls
 the other methods described here. If there is an exception, it catches and
 logs it.
 
-=item app_code
+=head2 app_code
 
 Called by C<run_app()> right at the beginning. Override this method in your
 application-specific subclass to do any initialization your application needs.
 
-=item app_finish
+=head2 app_finish
 
 Called by C<run_app()> within a C<try>/C<catch>-block. Override this method to
 do the actual application-specific work.
 
-=item app_init
+=head2 app_init
 
 Called by C<run_app()> right before the end. Override this method to do any
 cleanup your application needs.
 
-=item C<clear_initialized>
+=head1 INSTALLATION
 
-    $obj->clear_initialized;
-
-Clears the boolean value by setting it to 0.
-
-=item C<initialized>
-
-    $obj->initialized($value);
-    my $value = $obj->initialized;
-
-If called without an argument, returns the boolean value (0 or 1). If called
-with an argument, it normalizes it to the boolean value. That is, the values
-0, undef and the empty string become 0; everything else becomes 1.
-
-=item C<initialized_clear>
-
-    $obj->initialized_clear;
-
-Clears the boolean value by setting it to 0.
-
-=item C<initialized_set>
-
-    $obj->initialized_set;
-
-Sets the boolean value to 1.
-
-=item C<set_initialized>
-
-    $obj->set_initialized;
-
-Sets the boolean value to 1.
-
-=back
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Class-Scaffold/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHORS
 
-Florian Helmberger C<< <fh@univie.ac.at> >>
-
-Achim Adam C<< <ac@univie.ac.at> >>
-
-Mark Hofstetter C<< <mh@univie.ac.at> >>
-
-Heinz Ekker C<< <ek@univie.ac.at> >>
-
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
+  Florian Helmberger <fh@univie.ac.at>
+  Achim Adam <ac@univie.ac.at>
+  Mark Hofstetter <mh@univie.ac.at>
+  Heinz Ekker <ek@univie.ac.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2009 by the authors.
+This software is copyright (c) 2008 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
