@@ -1,11 +1,14 @@
-package Class::Scaffold::Introspect;
+use 5.008;
 use warnings;
 use strict;
+
+package Class::Scaffold::Introspect;
+our $VERSION = '1.100760';
+# ABSTRACT: Find configuration files within the framework
 use FindBin '$Bin';
 use Cwd;
 use File::Spec::Functions qw/curdir updir rootdir rel2abs/;
 use Sys::Hostname;
-our $VERSION = '0.16';
 use Exporter qw(import);
 our %EXPORT_TAGS = (conf => [qw/find_conf_file/],);
 our @EXPORT_OK = @{ $EXPORT_TAGS{all} = [ map { @$_ } values %EXPORT_TAGS ] };
@@ -36,7 +39,8 @@ sub find_conf_file {
     # cd t; perl sometest.t
     # perl /abs/path/to/distro/t/sometest.t
     chdir($Bin) or die "can't chdir to [$Bin]: $!\n";
-    my $distro_root = find_file_upwards('Makefile.PL');
+    my $distro_root = find_file_upwards('Makefile.PL')
+        || find_file_upwards('dist.ini');
     unless (defined $distro_root && length $distro_root) {
         warn "can't find distro root from [$Bin]\n";
         warn "might not be able to find conf file using [$ENV{CF_CONF}]\n"
@@ -55,59 +59,66 @@ sub find_conf_file {
     undef;
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
-Class::Scaffold::Introspect - large-scale OOP application support
+Class::Scaffold::Introspect - Find configuration files within the framework
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    Class::Scaffold::Introspect->new;
-
-=head1 DESCRIPTION
+version 1.100760
 
 =head1 METHODS
 
-=over 4
+=head2 find_conf_file
 
-=back
+FIXME
+
+=head2 find_file_upwards
+
+FIXME
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Class-Scaffold/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHORS
 
-Florian Helmberger C<< <fh@univie.ac.at> >>
-
-Achim Adam C<< <ac@univie.ac.at> >>
-
-Mark Hofstetter C<< <mh@univie.ac.at> >>
-
-Heinz Ekker C<< <ek@univie.ac.at> >>
-
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
+  Florian Helmberger <fh@univie.ac.at>
+  Achim Adam <ac@univie.ac.at>
+  Mark Hofstetter <mh@univie.ac.at>
+  Heinz Ekker <ek@univie.ac.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2009 by the authors.
+This software is copyright (c) 2008 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
