@@ -1,13 +1,16 @@
-package Class::Scaffold::Test;
-use strict;
+use 5.008;
 use warnings;
+use strict;
+
+package Class::Scaffold::Test;
+our $VERSION = '1.100760';
+# ABSTRACT: Base classes for framework test classes
 use Test::More;
 use Class::Value;    # see run() below
-our $VERSION = '0.16';
 
 # Also inherit from Class::Scaffold::Base so we get a delegate; put it first
 # so its new() is found, not the very basic new() from Project::Build::Test
-use base qw(
+use parent qw(
   Class::Scaffold::Base
   Test::CompanionClasses::Base
 );
@@ -40,59 +43,70 @@ sub run {
     is($Class::Value::SkipChecks, 1, '$Class::Value::SkipChecks is on');
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
-Class::Scaffold::Test - large-scale OOP application support
+Class::Scaffold::Test - Base classes for framework test classes
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    Class::Scaffold::Test->new;
-
-=head1 DESCRIPTION
+version 1.100760
 
 =head1 METHODS
 
-=over 4
+=head2 obj_ok
 
-=back
+FIXME
+
+=head2 planned_test_count
+
+FIXME
+
+=head2 run
+
+FIXME
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Class-Scaffold>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Class-Scaffold/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHORS
 
-Florian Helmberger C<< <fh@univie.ac.at> >>
-
-Achim Adam C<< <ac@univie.ac.at> >>
-
-Mark Hofstetter C<< <mh@univie.ac.at> >>
-
-Heinz Ekker C<< <ek@univie.ac.at> >>
-
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
+  Florian Helmberger <fh@univie.ac.at>
+  Achim Adam <ac@univie.ac.at>
+  Mark Hofstetter <mh@univie.ac.at>
+  Heinz Ekker <ek@univie.ac.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2009 by the authors.
+This software is copyright (c) 2008 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
